@@ -11,24 +11,21 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
-from typing import List, Any
+from dataclasses import dataclass, field
+from typing import List, Optional
 
 
-class SslConfiguration(object):
-    trust_store_path = None  # type: str
-
-    def __init__(self, trust_store_path):
-        # type: (str) -> None
-        self.trust_store_path = trust_store_path
+@dataclass
+class SslConfiguration:
+    trust_store_path: str
 
 
-class ServiceConfiguration(object):
-    api_token = None  # type: str
-    security = SslConfiguration  # type: Any
-    connect_timeout = None  # type: int
-    read_timeout = None  # type: int
-    write_timeout = None  # type: int
-    uris = []  # type: List[str]
-    max_num_retries = 3  # type: int
-    backoff_slot_size = 500  # type: int
+@dataclass
+class ServiceConfiguration:
+    api_token: Optional[str] = None
+    security: Optional[SslConfiguration] = None
+    uris: List[str] = field(default_factory=list)
+    connect_timeout: float = 10
+    read_timeout: float = 300
+    max_num_retries: int = 4
+    backoff_slot_size: int = 250
