@@ -14,17 +14,16 @@
 
 from .types import *
 
-
 __all__ = [
     "BinaryType",
     "ConjureBeanType",
     "ConjureEnumType",
     "ConjureFieldDefinition",
     "ConjureType",
-    "ConjureTypeType",
     "ConjureUnionType",
     "DecodableType",
     "DictType",
     "ListType",
     "OptionalType",
+    "OptionalTypeWrapper",
 ]
